import { getDevOpsCore } from '@thatdevops/core/devopsCore'
import path from 'path'

export async function devopsGit() {
	const { publishable = false, deployable = false } = getDevOpsCore()

	return [
		{
			label: 'Git & Packages',
			children: [
				{
					label: 'Commit',
					script: path.join(__dirname, 'src/commit'),
					paramQuestions: [
						{
							type: 'string',
							key: 'commitMessage',
							question: 'Enter commit message (optional)',
						},
						...(deployable
							? [
									{
										type: 'boolean',
										key: 'deploy',
										question: 'Trigger Amplify deployment?',
										default: 'n',
									},
							  ]
							: []),
					],
				},
				{
					label: 'Commit + Push',
					script: path.join(__dirname, 'src/commitPush'),
					default: true,
					paramQuestions: [
						{
							type: 'string',
							key: 'commitMessage',
							question: 'Enter commit message (optional)',
						},
						...(deployable
							? [
									{
										type: 'boolean',
										key: 'deploy',
										question: 'Trigger Amplify deployment?',
										default: 'n',
									},
							  ]
							: []),
					],
				},
				...(publishable
					? [
							{
								label: 'Commit + Push + Publish',
								script: path.join(__dirname, 'src/commitPushPublish'),
								paramQuestions: [
									{
										type: 'string',
										key: 'commitMessage',
										question: 'Enter commit message (optional)',
									},
									{
										type: 'boolean',
										key: 'force',
										question: 'Force publish?',
										default: 'n',
									},
									{
										type: 'stringList',
										key: 'bumpType',
										question: 'Version bump type?',
										list: [
											{ label: 'Patch', value: 'patch', default: true },
											{ label: 'Minor', value: 'minor' },
											{ label: 'Major', value: 'major' },
										],
									},
									...(deployable
										? [
												{
													type: 'boolean',
													key: 'deploy',
													question: 'Trigger Amplify deployment?',
													default: 'n',
												},
										  ]
										: []),
								],
							},
					  ]
					: []),

				{
					label: 'Resync Local Packages',
					script: path.join(__dirname, 'src/resyncLocalPackages'),
				},
				{
					label: 'Resync External Packages',
					script: path.join(__dirname, 'src/resyncExternalPackages'),
					...(publishable
						? {
								paramQuestions: [
									{
										type: 'boolean',
										key: 'publish',
										question: 'Publish after resync?',
										default: 'n',
									},
								],
						  }
						: {}),
				},
			],
		},
	]
}
export default devopsGit
