import getProjectPkgs from '@thatdevops/core/pkgman/getProjectPkgs'
import Pkg from '@thatdevops/core/pkgman/Pkg'

export async function doFindEffectedPackages(changedPkgs: Pkg[]): Promise<Pkg[]> {
	const allEffected = []
	let effected = await doFindNewEffectedPackages(changedPkgs)
	allEffected.push(...effected)
	while (effected.length) {
		const newEffected = await doFindNewEffectedPackages(effected)
		effected = newEffected.filter(p => !allEffected.find(p2 => p2.name === p.name))
		allEffected.push(...effected)
	}
	return allEffected
}

export default doFindEffectedPackages

async function doFindNewEffectedPackages(changedPkgs: Pkg[]): Promise<Pkg[]> {
	const pkgs = await getProjectPkgs()
	const effected = []
	for (const changedPkg of changedPkgs) {
		effected.push(changedPkg)
		for (const pkg of pkgs) {
			if (!effected.find(p => p.name === pkg.name)) {
				for (const depList of ['dependencies', 'devDependencies']) {
					const deps = pkg.json[depList]
					for (const depName in deps) {
						if (depName === changedPkg.name) {
							effected.push(pkg)
						}
					}
				}
			}
		}
	}
	return effected
}
